@@ -1,7 +1,7 @@
 /*
  * Tlf - contest logging program for amateur radio operators
  * Copyright (C) 2001-2002-2003 Rein Couperus <pa0rct@amsat.org>
- * 		 2011 Thomas Beierlein <tb@forth-ev.de>
+ * 		 2011, 2013 Thomas Beierlein <tb@forth-ev.de>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -19,11 +19,12 @@
  */
 	/* ------------------------------------------------------------
 	 *
-	 *              Read country data  from disk
+	 *              Read country data  from disk file cty.dat
 	 *--------------------------------------------------------------*/
 
 #include "dxcc.h"
 #include "readctydata.h"
+#include <glib.h>
 #ifdef HAVE_CONFIG_H
 #	include <config.h>
 #endif
@@ -42,7 +43,7 @@ int readctydata(void)
 	strcat(ctydb_location, "/cty.dat");
 
 	if ((fp_db = fopen(ctydb_location, "r")) == NULL) {
-	    mvprintw(4, 0, "Error opening cty.dat  file.\n");
+	    mvprintw(4, 0, "Error opening cty.dat file.\n");
 	    refreshp();
 	    sleep(5);
 	    endwin();
@@ -56,17 +57,9 @@ int readctydata(void)
     // set default for empty country
     dxcc_add("Not Specified        :    --:  --:  --:  -00.00:    00.00:     0.0:     :");
 
-/* read  ctydb.dat file ---------------------------------------------------- */
-
-
     while (fgets(buf, sizeof(buf), fp_db) != NULL) {
 
-	/* drop CR and/or NL */
-	if ((loc = strpbrk(buf, "\r\n")))
-	    *loc = '\0';
-	/* else {
-	 * Fehlermeldung 'string too long */
-
+	g_strchomp(buf); 	/* drop CR and/or NL and */
 	if (*buf == '\0')	/* ignore empty lines */
 	    continue;
 
